==> rearm-2.4.9%2B1.21.1-fabric-sources.jar: me/pajic/rearm/mixin/PlayerMixin.java <==
package me.pajic.rearm.mixin;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.sugar.Local;
import com.llamalad7.mixinextras.sugar.Share;
import com.llamalad7.mixinextras.sugar.ref.LocalRef;
import me.pajic.rearm.ReArm;
import me.pajic.rearm.ability.CriticalCounterAbility;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_7924;
import org.jetbrains.annotations.NotNull;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.*;
import org.spongepowered.asm.mixin.injection.invoke.arg.Args;
//? if 1.21.1 {
import com.llamalad7.mixinextras.injector.wrapmethod.WrapMethod;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
//?}

import java.util.List;

@SuppressWarnings("ConstantConditions")
@Mixin(value = class_1657.class, priority = 250)
public abstract class PlayerMixin extends class_1309 {

    @Shadow public abstract @NotNull class_1799 method_59958();

    protected PlayerMixin(class_1299<? extends class_1309> entityType, class_1937 level) {
        super(entityType, level);
    }

    @SuppressWarnings("resource")
    @ModifyArgs(
            method = "attack",
            at = @At(
                    value = "INVOKE",
					//? if fabric
                    target = "Lnet/minecraft/world/phys/AABB;inflate(DDD)Lnet/minecraft/world/phys/AABB;"
					//? if neoforge
					/*target = "Lnet/minecraft/world/item/ItemStack;getSweepHitBox(Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/world/entity/Entity;)Lnet/minecraft/world/phys/AABB;"*/
            )
    )
    private void sweepingEdge_increaseAttackRadius(Args args) {
        if (ReArm.CONFIG.sword.improvedSweepingEdge.get()) {
            int sweepingEdgeLevel = class_1890.method_8225(
                    //? if 1.21.1
                    method_37908().method_30349().method_30530(class_7924.field_41265).method_40290(class_1893.field_9115),
                    //? if > 1.21.1
                    /*level().registryAccess().lookupOrThrow(Registries.ENCHANTMENT).getOrThrow(Enchantments.SWEEPING_EDGE),*/
                    method_59958()
            );
            if (sweepingEdgeLevel > 0) {
                args.set(0, (double) args.get(0) * sweepingEdgeLevel);
                args.set(2, (double) args.get(2) * sweepingEdgeLevel);
                if (sweepingEdgeLevel >= 3) {
                    args.set(1, 1.0);
                }
            }
        }
    }

    @ModifyExpressionValue(
            method = "attack",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/level/Level;getEntitiesOfClass(Ljava/lang/Class;Lnet/minecraft/world/phys/AABB;)Ljava/util/List;"
            )
    )
    private <T extends class_1297> List<T> sweepingEdge_getHitEntities(
            List<T> original, @Share("original") LocalRef<List<T>> hitEntityList
    ) {
        if (ReArm.CONFIG.sword.improvedSweepingEdge.get()) {
            hitEntityList.set(original);
        }
        return original;
    }

    @ModifyArg(
            method = "attack",
            at = @At(
                    value = "INVOKE",
                    //? if 1.21.1
                    target = "Lnet/minecraft/world/entity/LivingEntity;hurt(Lnet/minecraft/world/damagesource/DamageSource;F)Z"
                    //? if > 1.21.1
                    /*target = "Lnet/minecraft/world/entity/LivingEntity;hurtServer(Lnet/minecraft/server/level/ServerLevel;Lnet/minecraft/world/damagesource/DamageSource;F)Z"*/
            ),
            index = /*? if 1.21.1 {*/1/*?} else {*//*2*//*?}*/
    )
    private <T extends class_1297> float sweepingEdge_increaseDamage(
            float damage, @Share("original") LocalRef<List<T>> hitEntityList, @Local(ordinal = 2) float h
    ) {
        if (ReArm.CONFIG.sword.improvedSweepingEdge.get()) {
            float additionalDamage = ReArm.CONFIG.sword.sweepingEdgeAdditionalDamagePerMob.get() *
                    Math.min(hitEntityList.get().size() - 1, ReArm.CONFIG.sword.maxMobAmountUsedForDamageIncrease.get());
            return damage + additionalDamage * h;
        }
        return damage;
    }

	@SuppressWarnings({"MixinAnnotationTarget", "InvalidInjectorMethodSignature"})
    @ModifyVariable(
            method = "attack",
            at = @At("STORE"),
            ordinal = 2
    )
    private boolean criticalCounter_critOnlyIfCriticalCounter(boolean original) {
        if (
                (class_1657) (Object) this instanceof class_3222 serverPlayer &&
                CriticalCounterAbility.canCounter(method_59958())
        ) {
            return CriticalCounterAbility.getPlayerCounterCondition(serverPlayer.method_5667()) ||
					(CriticalCounterAbility.canVanillaCrit(method_59958()) && original);
        }
        return original;
    }

    //? if 1.21.1 {
    @WrapMethod(method = "hurtCurrentlyUsedShield")
    private void criticalCounter_startTimer(float damageAmount, Operation<Void> original) {
        original.call(damageAmount);
        if (
                !field_6277.method_7960() &&
                (class_1657) (Object) this instanceof class_3222 serverPlayer &&
                CriticalCounterAbility.canCounter(method_59958())
        ) {
            ReArm.xplat().sendToClient(serverPlayer, new CriticalCounterAbility.S2CStartCriticalCounterTimer());
        }
    }
    //?}

    @SuppressWarnings("resource")
    @ModifyExpressionValue(
            method = "getProjectile",
            at = @At(
                    //? if (fabric && 1.21.1) || neoforge {
                    value = "FIELD",
                    target = "Lnet/minecraft/world/entity/player/Abilities;instabuild:Z"
                    //?}
                    //? if fabric && >= 1.21.7 {
                    /*value = "INVOKE",
                    target = "Lnet/minecraft/world/entity/player/Player;hasInfiniteMaterials()Z"
                    *///?}
            )
    )
    private boolean infinityFix(boolean original, @Local(argsOnly = true) class_1799 weaponStack) {
        if (ReArm.CONFIG.tweaks.infinityFix.get()) {
            int infinityLevel = class_1890.method_8225(
                    //? if 1.21.1
                    method_37908().method_30349().method_30530(class_7924.field_41265).method_40290(class_1893.field_9125),
                    //? if >= 1.21.7
                    /*level().registryAccess().lookupOrThrow(Registries.ENCHANTMENT).getOrThrow(Enchantments.INFINITY),*/
                    weaponStack
            );
            return original || infinityLevel > 0;
        }
        return original;
    }
}

==> rearm-2.4.10%2B1.21.10-fabric-sources.jar: me/pajic/rearm/mixin/PlayerMixin.java <==
package me.pajic.rearm.mixin;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.sugar.Local;
import com.llamalad7.mixinextras.sugar.Share;
import com.llamalad7.mixinextras.sugar.ref.LocalRef;
import me.pajic.rearm.ReArm;
import me.pajic.rearm.ability.CriticalCounterAbility;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_7924;
import org.jetbrains.annotations.NotNull;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.*;
import org.spongepowered.asm.mixin.injection.invoke.arg.Args;
//? if 1.21.1 {
/*import com.llamalad7.mixinextras.injector.wrapmethod.WrapMethod;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
*///?}

import java.util.List;

@SuppressWarnings("ConstantConditions")
@Mixin(value = class_1657.class, priority = 250)
public abstract class PlayerMixin extends class_1309 {

    @Shadow public abstract @NotNull class_1799 method_59958();

    protected PlayerMixin(class_1299<? extends class_1309> entityType, class_1937 level) {
        super(entityType, level);
    }

    @SuppressWarnings("resource")
    @ModifyArgs(
            method = "attack",
            at = @At(
                    value = "INVOKE",
					//? if fabric
                    target = "Lnet/minecraft/world/phys/AABB;inflate(DDD)Lnet/minecraft/world/phys/AABB;"
					//? if neoforge
					/*target = "Lnet/minecraft/world/item/ItemStack;getSweepHitBox(Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/world/entity/Entity;)Lnet/minecraft/world/phys/AABB;"*/
            )
    )
    private void sweepingEdge_increaseAttackRadius(Args args) {
        if (ReArm.CONFIG.sword.improvedSweepingEdge.get()) {
            int sweepingEdgeLevel = class_1890.method_8225(
                    //? if 1.21.1
                    /*level().registryAccess().registryOrThrow(Registries.ENCHANTMENT).getHolderOrThrow(Enchantments.SWEEPING_EDGE),*/
                    //? if > 1.21.1
                    method_73183().method_30349().method_30530(class_7924.field_41265).method_46747(class_1893.field_9115),
                    method_59958()
            );
            if (sweepingEdgeLevel > 0) {
                args.set(0, (double) args.get(0) * sweepingEdgeLevel);
                args.set(2, (double) args.get(2) * sweepingEdgeLevel);
                if (sweepingEdgeLevel >= 3) {
                    args.set(1, 1.0);
                }
            }
        }
    }

    @ModifyExpressionValue(
            method = "attack",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/level/Level;getEntitiesOfClass(Ljava/lang/Class;Lnet/minecraft/world/phys/AABB;)Ljava/util/List;"
            )
    )
    private <T extends class_1297> List<T> sweepingEdge_getHitEntities(
            List<T> original, @Share("original") LocalRef<List<T>> hitEntityList
    ) {
        if (ReArm.CONFIG.sword.improvedSweepingEdge.get()) {
            hitEntityList.set(original);
        }
        return original;
    }

    @ModifyArg(
            method = "attack",
            at = @At(
                    value = "INVOKE",
                    //? if 1.21.1
                    /*target = "Lnet/minecraft/world/entity/LivingEntity;hurt(Lnet/minecraft/world/damagesource/DamageSource;F)Z"*/
                    //? if > 1.21.1
                    target = "Lnet/minecraft/world/entity/LivingEntity;hurtServer(Lnet/minecraft/server/level/ServerLevel;Lnet/minecraft/world/damagesource/DamageSource;F)Z"
            ),
            index = /*? if 1.21.1 {*//*1*//*?} else {*/2/*?}*/
    )
    private <T extends class_1297> float sweepingEdge_increaseDamage(
            float damage, @Share("original") LocalRef<List<T>> hitEntityList, @Local(ordinal = 2) float h
    ) {
        if (ReArm.CONFIG.sword.improvedSweepingEdge.get()) {
            float additionalDamage = ReArm.CONFIG.sword.sweepingEdgeAdditionalDamagePerMob.get() *
                    Math.min(hitEntityList.get().size() - 1, ReArm.CONFIG.sword.maxMobAmountUsedForDamageIncrease.get());
            return damage + additionalDamage * h;
        }
        return damage;
    }

	@SuppressWarnings({"MixinAnnotationTarget", "InvalidInjectorMethodSignature"})
    @ModifyVariable(
            method = "attack",
            at = @At("STORE"),
            ordinal = 2
    )
    private boolean criticalCounter_critOnlyIfCriticalCounter(boolean original) {
        if (
                (class_1657) (Object) this instanceof class_3222 serverPlayer &&
                CriticalCounterAbility.canCounter(method_59958())
        ) {
            return CriticalCounterAbility.getPlayerCounterCondition(serverPlayer.method_5667()) ||
					(CriticalCounterAbility.canVanillaCrit(method_59958()) && original);
        }
        return original;
    }

    //? if 1.21.1 {
    /*@WrapMethod(method = "hurtCurrentlyUsedShield")
    private void criticalCounter_startTimer(float damageAmount, Operation<Void> original) {
        original.call(damageAmount);
        if (
                !useItem.isEmpty() &&
                (Player) (Object) this instanceof ServerPlayer serverPlayer &&
                CriticalCounterAbility.canCounter(getWeaponItem())
        ) {
            ReArm.xplat().sendToClient(serverPlayer, new CriticalCounterAbility.S2CStartCriticalCounterTimer());
        }
    }
    *///?}

    @SuppressWarnings("resource")
    @ModifyExpressionValue(
            method = "getProjectile",
            at = @At(
                    //? if (fabric && 1.21.1) || neoforge {
                    /*value = "FIELD",
                    target = "Lnet/minecraft/world/entity/player/Abilities;instabuild:Z"
                    *///?}
                    //? if fabric && >= 1.21.7 {
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/entity/player/Player;hasInfiniteMaterials()Z"
                    //?}
            )
    )
    private boolean infinityFix(boolean original, @Local(argsOnly = true) class_1799 weaponStack) {
        if (ReArm.CONFIG.tweaks.infinityFix.get()) {
            int infinityLevel = class_1890.method_8225(
                    //? if 1.21.1
                    /*level().registryAccess().registryOrThrow(Registries.ENCHANTMENT).getHolderOrThrow(Enchantments.INFINITY),*/
                    //? if >= 1.21.7
                    method_73183().method_30349().method_30530(class_7924.field_41265).method_46747(class_1893.field_9125),
                    weaponStack
            );
            return original || infinityLevel > 0;
        }
        return original;
    }
}
